@@ -21,9 +21,9 @@ pub mod prelude {
     pub use elbus::client::AsyncClient;
     pub use elbus::rpc::{Rpc, RpcClient, RpcError, RpcEvent, RpcHandlers, RpcResult};
     pub use elbus::{Frame, QoS};
+    pub use eva_common::err_logger;
     pub use eva_common::services::Registry;
     pub use eva_common::services::{Initial, ServiceInfo, ServiceMethod};
-    pub use eva_common::tools::ErrLogger;
     pub use eva_common::{EResult, Error};
     pub use log::{debug, error, info, trace, warn};
 }
